/**
 * Generates custom checkout functionality
 *
 * @package Fortis for WooCommerce
 */

jQuery( document ).ready(
	function ($) {

		function wooCommerceValidation() {
			jQuery( '.woocommerce-notices-wrapper' ).html( '' );
			let valid = true;
			jQuery.ajax(
				{
					async: false,
					type: 'post',
					data: jQuery( '.checkout' ).serialize(),
					url: '?wc-ajax=checkout',
					success: function (response) {
						if (response['result'] === 'failure') {
							valid = false;
							jQuery( '.woocommerce-notices-wrapper:last' ).append( response['messages'] );
							window.scrollTo( 0, findPosition( jQuery( '.woocommerce-notices-wrapper' )[0] ) );
						}
					}
				}
			);
			return valid;
		}

		function relocateOrderButton(isFortis) {
			const paymentMethod = document.querySelector( 'input[name="payment_method"]:checked' );

			const orderBtn = document.getElementById( 'place_order' );

			if (isFortis) {
				paymentMethod.closest( '.wc_payment_method' ).appendChild( orderBtn );
			} else {
				document.getElementsByClassName( 'place-order' )[0].appendChild( orderBtn );
			}
		}

		function findPosition(obj) {
			let currenttop = 0;
			if (obj.offsetParent) {
				do {
					currenttop += obj.offsetTop;
				} while ((obj = obj.offsetParent));
				return [currenttop];
			}
		}

		$( document ).ajaxComplete(
			function (event, xhr, settings) {
				// Check if the AJAX call is related to WooCommerce update order review.
				if (settings.url.indexOf( 'update_order_review' ) !== -1) {
					console.log( 'WooCommerce update order review AJAX call finished' );

					$( '#place_order' ).click(
						function (e) {
							if (document.querySelector( '#payment_method_fortis:checked' )) {
								e.preventDefault();
								if (wooCommerceValidation() === true) {
									jQuery( '#place_order' ).hide();
									const fortisIFrameContainer = $( '#fortisIFrameContainer' );
									fortisIFrameContainer.html( '<div>Loading...</div>' );
									jQuery.ajax(
										{
											url: '/wp-admin/admin-ajax.php',
											async: false,
											type: 'post',
											data: {
												'action': 'generate_iframe_form',
												'fields': jQuery( '.checkout' ).serialize()
											},
											success: function (response) {
												fortisIFrameContainer.html( response );
											},
										}
									);
								}
							}
						}
					);

					// Call the function when the payment method is changed.
					document.addEventListener(
						'change',
						function (event) {
							const target = event.target;
							if (target && target.matches( 'input[id="payment_method_fortis"]' )) {
								relocateOrderButton( true );
							} else if (target && target.matches( 'input[name="payment_method"]' )) {
								relocateOrderButton( false );
							}
						}
					);

					if (document.querySelector( '#payment_method_fortis:checked' )) {
						relocateOrderButton( true );
					}
				}
			}
		);

	}
);
